import { FC, useEffect, useState } from "react";
import { NavItem, SideBarBox } from "../styles/TopBarStyle";
import { useNavigate } from "react-router";
import useComponentVisible from "../Hooks/useComponentVisible";

const NavigationMenu: FC = () => {
    const navigate = useNavigate();
    const handleClick = (loc: string) => navigate(loc);
    const locations: Array<string> = ["/", "/about", "CV", "/projects"];
    const [isPhone, setIsPhone] = useState(
        window.matchMedia("(min-width: 720px)").matches
    );
    const locationButtons = locations.map((location) => (
        <NavItem onClick={() => handleClick(location)}>{location}</NavItem>
    ));

    const { ref, isCompVisible, openComp } = useComponentVisible(false);

    useEffect(() => {
        const recheckIsPhone = () => {
            setIsPhone(window.matchMedia("(min-width: 720px)").matches);
        };

        window.addEventListener("resize", recheckIsPhone);
    });

    return (
        <>
            {isPhone ? (
                locationButtons
            ) : (
                <>
                    <button onClick={() => openComp()}>
                        <span className="material-symbols-outlined">menu</span>
                    </button>
                    {isCompVisible && (
                        <SideBarBox ref={ref}>{locationButtons}</SideBarBox>
                    )}
                </>
            )}
        </>
    );
};

export default NavigationMenu;
